==> chromium_76.0.3809.87.orig.tar.xz: chromium-76.0.3809.87/chrome/browser/performance_manager/graph/node_base.cc <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/performance_manager/graph/node_base.h"

#include <utility>

#include "chrome/browser/performance_manager/graph/frame_node_impl.h"
#include "chrome/browser/performance_manager/graph/graph_impl.h"
#include "chrome/browser/performance_manager/graph/page_node_impl.h"
#include "chrome/browser/performance_manager/graph/process_node_impl.h"
#include "chrome/browser/performance_manager/graph/system_node_impl.h"
#include "chrome/browser/performance_manager/observers/graph_observer.h"

namespace performance_manager {

NodeBase::NodeBase(NodeTypeEnum node_type, GraphImpl* graph)
    : graph_(graph), type_(node_type) {}

NodeBase::~NodeBase() {
  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);

  // The node must have been removed from the graph before destruction.
  DCHECK(!graph_->NodeInGraph(this));
}

// static
int64_t NodeBase::GetSerializationId(NodeBase* node) {
  if (!node)
    return 0u;

  if (!node->serialization_id_)
    node->serialization_id_ = node->graph()->GetNextNodeSerializationId();

  DCHECK_NE(0u, node->serialization_id_);
  return node->serialization_id_;
}

// TODO(chrisha): Remove this!
void NodeBase::RemoveObserver(GraphObserver* observer) {
  switch (type()) {
    case NodeTypeEnum::kFrame:
      return FrameNodeImpl::FromNodeBase(this)->RemoveObserver(observer);
    case NodeTypeEnum::kPage:
      return PageNodeImpl::FromNodeBase(this)->RemoveObserver(observer);
    case NodeTypeEnum::kProcess:
      return ProcessNodeImpl::FromNodeBase(this)->RemoveObserver(observer);
    case NodeTypeEnum::kSystem:
      return SystemNodeImpl::FromNodeBase(this)->RemoveObserver(observer);
    case NodeTypeEnum::kInvalidType:
      NOTREACHED();
  }
}

void NodeBase::JoinGraph() {
  DCHECK(graph_->NodeInGraph(this));
}

void NodeBase::LeaveGraph() {
  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
  DCHECK(graph_->NodeInGraph(this));
}

}  // namespace performance_manager

==> chromium_78.0.3904.108.orig.tar.xz: chromium-78.0.3904.108/chrome/browser/performance_manager/graph/node_base.cc <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/performance_manager/graph/node_base.h"

#include "chrome/browser/performance_manager/graph/graph_impl.h"
#include "chrome/browser/performance_manager/public/graph/node.h"

namespace performance_manager {

// static
const uintptr_t NodeBase::kNodeBaseType =
    reinterpret_cast<uintptr_t>(&kNodeBaseType);

NodeBase::NodeBase(NodeTypeEnum node_type, GraphImpl* graph)
    : graph_(graph), type_(node_type) {}

NodeBase::~NodeBase() {
  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);

  // The node must have been removed from the graph before destruction.
  DCHECK(!graph_->NodeInGraph(this));
}

// static
int64_t NodeBase::GetSerializationId(NodeBase* node) {
  if (!node)
    return 0u;

  if (!node->serialization_id_)
    node->serialization_id_ = node->graph()->GetNextNodeSerializationId();

  DCHECK_NE(0u, node->serialization_id_);
  return node->serialization_id_;
}

// static
const NodeBase* NodeBase::FromNode(const Node* node) {
  CHECK_EQ(kNodeBaseType, node->GetImplType());
  return reinterpret_cast<const NodeBase*>(node->GetImpl());
}

// static
NodeBase* NodeBase::FromNode(Node* node) {
  CHECK_EQ(kNodeBaseType, node->GetImplType());
  return reinterpret_cast<NodeBase*>(const_cast<void*>(node->GetImpl()));
}

void NodeBase::JoinGraph() {
  DCHECK(graph_->NodeInGraph(this));
}

void NodeBase::LeaveGraph() {
  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
  DCHECK(graph_->NodeInGraph(this));
}

}  // namespace performance_manager
